ml4gw package
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   ml4gw.dataloading
   ml4gw.nn
   ml4gw.transforms
   ml4gw.waveforms

Submodules
----------

ml4gw.augmentations module
--------------------------

.. automodule:: ml4gw.augmentations
   :members:
   :undoc-members:
   :show-inheritance:

ml4gw.distributions module
--------------------------

.. automodule:: ml4gw.distributions
   :members:
   :undoc-members:
   :show-inheritance:

ml4gw.gw module
---------------

.. automodule:: ml4gw.gw
   :members:
   :undoc-members:
   :show-inheritance:

ml4gw.spectral module
---------------------

.. automodule:: ml4gw.spectral
   :members:
   :undoc-members:
   :show-inheritance:

ml4gw.types module
------------------

.. automodule:: ml4gw.types
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ml4gw
   :members:
   :undoc-members:
   :show-inheritance:
